.. _mockfs-api:

``os.path`` and ``glob`` Implementations
========================================
.. automodule:: mockfs.mfs
   :members:
   :undoc-members:

Utility Functions
=================
.. automodule:: mockfs.util
   :members:
   :undoc-members:

File Storage and IO
===================
.. automodule:: mockfs.storage
   :members:
   :undoc-members:

